From 52a4c4d82f9c5b808e6c61fd51c1c70e42865565 Mon Sep 17 00:00:00 2001
From: Justin Clarke Casey
Date: Fri, 12 Sep 2008 20:12:03 +0000
Subject: * Check in first part of
http://opensimulator.org/mantis/view.php?id=2073 * This patch aims to
introduce look at direction persistence between logins. It won't be active
until the second part of the patch is committed in about two weeks time. At
this point, region servers that haven't upgraded past this revision may run
into problems * This checkin upgrades the user database. As always, we
recommend you have backups in case something goes wrong. * Many thanks to
tyre for this patch.
---
.../Region/Communications/OGS1/OGS1UserServices.cs | 35 ++++++++++++++++------
1 file changed, 26 insertions(+), 9 deletions(-)
(limited to 'OpenSim/Region/Communications/OGS1')
diff --git a/OpenSim/Region/Communications/OGS1/OGS1UserServices.cs b/OpenSim/Region/Communications/OGS1/OGS1UserServices.cs
index 36a82a8..b8268eb 100644
--- a/OpenSim/Region/Communications/OGS1/OGS1UserServices.cs
+++ b/OpenSim/Region/Communications/OGS1/OGS1UserServices.cs
@@ -235,19 +235,22 @@ namespace OpenSim.Region.Communications.OGS1
/// Logs off a user on the user server
///
/// UUID of the user
- /// UUID of the Region
- /// final position x
- /// final position y
- /// final position z
- public void LogOffUser(UUID userid, UUID regionid, ulong regionhandle, float posx, float posy, float posz)
+ /// UUID of the Region
+ /// regionhandle
+ /// final position
+ /// final lookat
+ public void LogOffUser(UUID userid, UUID regionid, ulong regionhandle, Vector3 position, Vector3 lookat)
{
Hashtable param = new Hashtable();
param["avatar_uuid"] = userid.Guid.ToString();
param["region_uuid"] = regionid.Guid.ToString();
param["region_handle"] = regionhandle.ToString();
- param["region_pos_x"] = posx.ToString();
- param["region_pos_y"] = posy.ToString();
- param["region_pos_z"] = posz.ToString();
+ param["region_pos_x"] = position.X.ToString();
+ param["region_pos_y"] = position.Y.ToString();
+ param["region_pos_z"] = position.Z.ToString();
+ param["lookat_x"] = lookat.X.ToString();
+ param["lookat_y"] = lookat.Y.ToString();
+ param["lookat_z"] = lookat.Z.ToString();
IList parameters = new ArrayList();
parameters.Add(param);
@@ -263,6 +266,20 @@ namespace OpenSim.Region.Communications.OGS1
}
}
+ ///
+ /// Logs off a user on the user server (deprecated as of 2008-08-27)
+ ///
+ /// UUID of the user
+ /// UUID of the Region
+ /// regionhandle
+ /// final position x
+ /// final position y
+ /// final position z
+ public void LogOffUser(UUID userid, UUID regionid, ulong regionhandle, float posx, float posy, float posz)
+ {
+ LogOffUser(userid, regionid, regionhandle, new Vector3(posx, posy, posz), new Vector3());
+ }
+
public UserProfileData GetUserProfile(string firstName, string lastName)
{
return GetUserProfile(firstName + " " + lastName);
@@ -672,7 +689,7 @@ namespace OpenSim.Region.Communications.OGS1
}
}
///
- /// Returns a list of FriendsListItems that describe the friends and permissions in the friend relationship for LLUUID friendslistowner
+ /// Returns a list of FriendsListItems that describe the friends and permissions in the friend relationship for UUID friendslistowner
///
/// The agent that we're retreiving the friends Data.
public List GetUserFriendList(UUID friendlistowner)
--
cgit v1.1